@@ -52,7 +52,7 @@ class Storage(object):
 
         Should return public_url to the file in storage if successful.
         """
-        return self._upload_cache(canonical_filename, cache_filepath)
+        return self._upload_output(canonical_filename, cache_filepath)
 
     def _upload_output(self, canonical_filename, cache_filepath):
         """
